#!/usr/bin/env bash
cd test
python AltitudeDetectorTest.py
python NodeDetectorTest.py
python ImpulseManeuverTest.py
python BackAndForthDetectorTest.py
python KeplerianConverterTest.py
python EventHandlerTest.py
python TestAbstractDetector.py
python EventDetectorTest.py
python SmallManeuverAnalyticalModelTest.py
python GroundFieldOfViewDetectorTest.py
